@@ -5,12 +5,12 @@ require 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '3.47';
+our $VERSION = '3.48';
 $VERSION = eval $VERSION;
 
-use Object::InsideOut::Exception 3.47;
-use Object::InsideOut::Util 3.47 qw(create_object hash_re is_it make_shared);
-use Object::InsideOut::Metadata 3.47;
+use Object::InsideOut::Exception 3.48;
+use Object::InsideOut::Util 3.48 qw(create_object hash_re is_it make_shared);
+use Object::InsideOut::Metadata 3.48;
 
 require B;
 
@@ -124,10 +124,10 @@ sub import
     }
 
     # Invoked via inheritance - ignore
-    if ($self ne __PACKAGE__) {
+    if ($self ne 'Object::InsideOut') {
         if (Exporter->can('import')) {
             my $lvl = $Exporter::ExportLevel;
-            $Exporter::ExportLevel = (caller() eq __PACKAGE__) ? 3 : 1;
+            $Exporter::ExportLevel = (caller() eq 'Object::InsideOut') ? 3 : 1;
             $self->Exporter::import(@_);
             $Exporter::ExportLevel = $lvl;
         }
@@ -277,7 +277,7 @@ sub import
 
     # Add Object::InsideOut to class's @ISA array, if needed
     if ($need_oio) {
-        push(@{$class.'::ISA'}, __PACKAGE__);
+        push(@{$class.'::ISA'}, 'Object::InsideOut');
     }
 
     # Add calling class to tree
@@ -704,38 +704,64 @@ sub initialize :Sub(Private)
     no warnings 'redefine';
     no strict 'refs';
 
+    # Purge existing references to the default :ID sub (i.e., _ID)
+    #   if no objects exist in that heirarchy
+    my $id_subs = $GBL{'sub'}{'id'};
+    my $obj_ids = $GBL{'id'}{'obj'};
+    foreach my $class (keys(%{$trees})) {
+        foreach my $pkg (@{$$trees{$class}}) {
+            if (exists($$id_subs{$pkg}) &&
+                ($$id_subs{$pkg}{'code'} == \&_ID) &&
+                ! exists($$obj_ids{$$id_subs{$pkg}{'pkg'}}))
+            {
+                delete($$id_subs{$pkg});
+            }
+        }
+    }
+
     my $reapply = 1;
     while ($reapply) {
         $reapply = 0;
 
         # Propagate ID subs through the class hierarchies
-        my $id_subs = $GBL{'sub'}{'id'};
         foreach my $class (keys(%{$trees})) {
             # Find ID sub for this class somewhere in its hierarchy
             my $id_sub_pkg;
             foreach my $pkg (@{$$trees{$class}}) {
-                if ($$id_subs{$pkg}) {
-                    if ($id_sub_pkg) {
-                        # Verify that all the ID subs in hierarchy are the same
-                        if (($$id_subs{$pkg}{'code'}
-                                != $$id_subs{$id_sub_pkg}{'code'}) ||
-                            ($$id_subs{$pkg}{'pkg'}
-                                ne $$id_subs{$id_sub_pkg}{'pkg'}))
-                        {
-                            my ($p,    $file,  $line)  = @{$$id_subs{$pkg}{'loc'}};
-                            my ($pkg2, $file2, $line2) = @{$$id_subs{$id_sub_pkg}{'loc'}};
-                            OIO::Attribute->die(
-                                'message' => "Multiple :ID subs defined within hierarchy for '$class'",
-                                'Info'    => ":ID subs in class '$pkg' (file '$file', line $line), and class '$pkg2' (file '$file2' line $line2)");
-                        }
-                    } else {
-                        $id_sub_pkg = $pkg;
+                next if (! exists($$id_subs{$pkg}));
+                if (! defined($id_sub_pkg)) {
+                    $id_sub_pkg = $pkg;
+                    next;
+                }
+                # Verify that all the ID subs in hierarchy are the same
+                if (($$id_subs{$pkg}{'code'} != $$id_subs{$id_sub_pkg}{'code'}) ||
+                    ($$id_subs{$pkg}{'pkg'}  ne $$id_subs{$id_sub_pkg}{'pkg'}))
+                {
+                    # Runtime merging of heirarchies with existing objects
+                    if (($$id_subs{$pkg}{'code'} == \&_ID) ||
+                        ($$id_subs{$id_sub_pkg}{'code'} == \&_ID))
+                    {
+                        OIO::Runtime->die(
+                            'message' => "Possible extant objects prevent runtime creation of hierarchy for class '$class'",
+                            'Info'    => "Runtime loading of classes needs to be performed before any objects are created within their hierarchies",
+                            ((($$id_subs{$pkg}{'code'} == \&_ID) && ($$id_subs{$id_sub_pkg}{'code'} == \&_ID))
+                                ? ()
+                                : ('Class1'  => "The hierarchy for '$$id_subs{$pkg}{'pkg'}' is using object IDs generated by " .
+                                                (($$id_subs{$pkg}{'code'} == \&_ID) ? 'Object::InsideOut' : 'a custom :ID subroutine'),
+                                   'Class2'  => "The hierarchy for '$$id_subs{$id_sub_pkg}{'pkg'}' is using object IDs generated by " .
+                                                (($$id_subs{$id_sub_pkg}{'code'} == \&_ID) ? 'Object::InsideOut' : 'a custom :ID subroutine'))));
                     }
+                    # Multiple :ID subs in heirarchy
+                    my (undef, $file,  $line)  = @{$$id_subs{$pkg}{'loc'}};
+                    my (undef, $file2, $line2) = @{$$id_subs{$id_sub_pkg}{'loc'}};
+                    OIO::Attribute->die(
+                        'message' => "Multiple :ID subs defined within hierarchy for class '$class'",
+                        'Info'    => ":ID subs in class '$$id_subs{$pkg}{'pkg'}' (file '$file', line $line), and class '$$id_subs{$id_sub_pkg}{'pkg'}' (file '$file2', line $line2)");
                 }
             }
 
             # If ID sub found, propagate it through the class hierarchy
-            if ($id_sub_pkg) {
+            if (defined($id_sub_pkg)) {
                 foreach my $pkg (@{$$trees{$class}}) {
                     if (! exists($$id_subs{$pkg})) {
                         $$id_subs{$pkg} = $$id_subs{$id_sub_pkg};
@@ -751,9 +777,9 @@ sub initialize :Sub(Private)
                 if (! exists($$id_subs{$class})) {
                     # Default to internal ID sub and propagate it
                     $$id_subs{$class} = {
-                        pkg  => $class,
+                        pkg  => $$trees{$class}[0],
                         code => \&_ID,
-                        loc  => [ __PACKAGE__, __FILE__, '-' ],
+                        loc  => [ '', 'Default :ID sub', 0 ],
                     };
                     $reapply = 1;
                     last;
@@ -1115,7 +1141,7 @@ sub is_sharing :Sub(Private)
 sub CLONE
 {
     # Don't execute when called for sub-classes
-    return if ($_[0] ne __PACKAGE__);
+    return if ($_[0] ne 'Object::InsideOut');
 
     # Don't execute twice for same thread
     my $tid;
@@ -1505,7 +1531,7 @@ sub new :MergeArgs
     my $class = ref($thing) || $thing;
 
     # Can't call ->new() on this package
-    if ($class eq __PACKAGE__) {
+    if ($class eq 'Object::InsideOut') {
         OIO::Method->die('message' => q/'new' called on non-class 'Object::InsideOut'/);
     }
 
@@ -1668,7 +1694,7 @@ sub meta
     my $class = ref($_[0]) || $_[0];
 
     # No metadata for OIO
-    if ($class eq __PACKAGE__) {
+    if ($class eq 'Object::InsideOut') {
         OIO::Method->die('message' => q/'meta' called on non-class 'Object::InsideOut'/);
     }
 
@@ -2912,7 +2938,7 @@ initialize();
 # Initialize just before cloning a thread
 sub CLONE_SKIP
 {
-    if ($_[0] eq __PACKAGE__) {
+    if ($_[0] eq 'Object::InsideOut') {
         initialize();
     }
     return 0;
