@@ -64,7 +64,7 @@ sub install_ATTRIBUTES
     *Object::InsideOut::install_ATTRIBUTES = sub { };
 }
 
-add_meta(__PACKAGE__, {
+add_meta('Object::InsideOut', {
     'MODIFY_SCALAR_ATTRIBUTES' => {'hidden' => 1},
     'CHECK_ATTRS'              => {'hidden' => 1},
     'FETCH_ATTRS'              => {'hidden' => 1},
@@ -79,7 +79,7 @@ sub FETCH_CODE_ATTRIBUTES   :Sub { return (FETCH_ATTRS('CODE',   @_)); }
 
 
 # Ensure correct versioning
-($Object::InsideOut::VERSION == 3.47)
+($Object::InsideOut::VERSION == 3.48)
     or die("Version mismatch\n");
 
 # EOF
